@@ -17,10 +17,12 @@ class Attachment(object):
 		self.__size = None
 		self.__parent_id = None
 		self.__editable = None
+		self.__sharing_permission = None
 		self.__file_id = None
 		self.__type = None
 		self.__se_module = None
 		self.__modified_by = None
+		self.__attachment_type = None
 		self.__state = None
 		self.__id = None
 		self.__created_by = None
@@ -211,6 +213,30 @@ class Attachment(object):
 		self.__editable = editable
 		self.__key_modified['$editable'] = 1
 
+	def get_sharing_permission(self):
+		"""
+		The method to get the sharing_permission
+
+		Returns:
+			string: A string representing the sharing_permission
+		"""
+
+		return self.__sharing_permission
+
+	def set_sharing_permission(self, sharing_permission):
+		"""
+		The method to set the value to sharing_permission
+
+		Parameters:
+			sharing_permission (string) : A string representing the sharing_permission
+		"""
+
+		if sharing_permission is not None and not isinstance(sharing_permission, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: sharing_permission EXPECTED TYPE: str', None, None)
+		
+		self.__sharing_permission = sharing_permission
+		self.__key_modified['$sharing_permission'] = 1
+
 	def get_file_id(self):
 		"""
 		The method to get the file_id
@@ -312,6 +338,30 @@ class Attachment(object):
 		self.__modified_by = modified_by
 		self.__key_modified['Modified_By'] = 1
 
+	def get_attachment_type(self):
+		"""
+		The method to get the attachment_type
+
+		Returns:
+			int: An int representing the attachment_type
+		"""
+
+		return self.__attachment_type
+
+	def set_attachment_type(self, attachment_type):
+		"""
+		The method to set the value to attachment_type
+
+		Parameters:
+			attachment_type (int) : An int representing the attachment_type
+		"""
+
+		if attachment_type is not None and not isinstance(attachment_type, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: attachment_type EXPECTED TYPE: int', None, None)
+		
+		self.__attachment_type = attachment_type
+		self.__key_modified['$attachment_type'] = 1
+
 	def get_state(self):
 		"""
 		The method to get the state
