@@ -36,7 +36,7 @@ class Utility(object):
 
     apitype_vs_datatype = {}
     apitype_vs_structurename = {}
-    api_supported_module = {}
+    api_supported_modules = {}
     module_api_name = None
     new_file = False
     get_modified_modules = False
@@ -110,8 +110,8 @@ class Utility(object):
                 elif Initializer.get_initializer().sdk_config.get_auto_refresh_fields():
                     Utility.new_file = True
                     Utility.fill_data_type()
-                    if len(Utility.api_supported_module) == 0:
-                        Utility.api_supported_module = Utility.get_modules(None)               
+                    if len(Utility.api_supported_modules) == 0:
+                        Utility.api_supported_modules = Utility.get_modules(None)
                     record_field_details_json = Initializer.get_json(record_field_details_path) if os.path.exists(record_field_details_path) else {}
 
                     record_field_details_json[Constants.FIELDS_LAST_MODIFIED_TIME] = time.time() * 1000
